@@ -1,7 +1,9 @@
-# -*- coding: utf-8 -*-
 #
 # UCS test
 #
+# Like what you see? Join us!
+# https://www.univention.com/about-us/careers/vacancies/
+#
 # Copyright 2015-2022 Univention GmbH
 #
 # https://www.univention.de/
@@ -144,7 +146,7 @@ def get_docker_appbox_ucs():
 
 
 def get_docker_appbox_image():
-	image_name = 'docker-test.software-univention.de/ucs-appbox-amd64:{}-8'.format(get_docker_appbox_ucs())
+	image_name = f'docker-test.software-univention.de/ucs-appbox-amd64:{get_docker_appbox_ucs()}-8'
 	print('Using %s' % image_name)
 	return image_name
 
@@ -160,15 +162,13 @@ def get_latest_docker_appbox_image():
 
 
 def docker_login(server='docker.software-univention.de'):
-	ret = subprocess.call(['docker', 'login', '-u', 'ucs', '-p', 'readonly', server])
-	if ret != 0:
-		raise UCSTest_Docker_LoginFailed()
+	cmd = ['docker', 'login', '-u', 'ucs', '-p', 'readonly', server]
+	error_handling_call(cmd, exc=UCSTest_Docker_LoginFailed)
 
 
 def docker_pull(image, server='docker.software-univention.de'):
-	ret = subprocess.call(['docker', 'pull', '%s/%s' % (server, image)])
-	if ret != 0:
-		raise UCSTest_Docker_PullFailed()
+	cmd = ['docker', 'pull', '%s/%s' % (server, image)]
+	error_handling_call(cmd, exc=UCSTest_Docker_PullFailed)
 
 
 def docker_image_is_present(imgname):
@@ -226,7 +226,14 @@ def copy_package_to_appcenter(ucs_version, app_directory, package_name):
 	print(subprocess.check_output(command, shell=True, text=True))
 
 
-class App(object):
+def error_handling_call(*args, exc=Exception, **kwargs):
+	try:
+		print(subprocess.check_output(*args, **kwargs, stderr=subprocess.STDOUT).decode('UTF-8', 'replace'))
+	except subprocess.CalledProcessError as ex:
+		raise exc('%s: %s' % (ex, ex.output.decode('UTF-8', 'replace')))
+
+
+class App:
 
 	def __init__(self, name, version, container_version=None, app_directory_suffix=None, package_name=None, build_package=True, call_join_scripts=True):
 		self.app_name = name
@@ -286,7 +293,7 @@ class App(object):
 		print(repr(self))
 
 	def __repr__(self):
-		return '%s(app_name=%r, app_version=%r)' % (super(App, self).__repr__(), self.app_name, self.app_version)
+		return '%s(app_name=%r, app_version=%r)' % (super().__repr__(), self.app_name, self.app_version)
 
 	def set_ini_parameter(self, **kwargs):
 		for key, value in kwargs.items():
@@ -314,9 +321,7 @@ class App(object):
 		cmd.append('--pwdfile=%s' % self.admin_pwdfile)
 		cmd.append('%s=%s' % (self.app_name, self.app_version))
 		print(cmd)
-		ret = subprocess.call(' '.join(cmd), shell=True)
-		if ret != 0:
-			raise UCSTest_DockerApp_InstallationFailed()
+		error_handling_call(' '.join(cmd), shell=True, exc=UCSTest_DockerApp_InstallationFailed)
 
 		self.reload_container_id()
 
@@ -345,9 +350,7 @@ class App(object):
 			cmd.extend(['--set'] + set_vars)
 		if unset_vars:
 			cmd.extend(['--unset'] + unset_vars)
-		ret = subprocess.call(cmd)
-		if ret != 0:
-			raise UCSTest_DockerApp_ConfigureFailed()
+		error_handling_call(cmd, exc=UCSTest_DockerApp_ConfigureFailed)
 
 	def install_via_umc(self):
 		def _thread(event, options):
@@ -389,17 +392,13 @@ class App(object):
 			raise UCTTest_DockerApp_UMCInstallFailed(None, errors)
 
 	def _update(self):
-		ret = subprocess.call(['univention-app', 'update'])
-		if ret != 0:
-			raise UCSTest_DockerApp_UpdateFailed()
+		error_handling_call(['univention-app', 'update'], exc=UCSTest_DockerApp_UpdateFailed)
 
 	def register(self):
 		print('App.register()')
 		cmd = ['univention-app', 'register', '--app']
 		print(cmd)
-		ret = subprocess.call(' '.join(cmd), shell=True)
-		if ret != 0:
-			raise UCSTest_DockerApp_RegisterFailed()
+		error_handling_call(' '.join(cmd), shell=True, exc=UCSTest_DockerApp_RegisterFailed)
 
 	def upgrade(self):
 		print('App.upgrade()')
@@ -412,22 +411,16 @@ class App(object):
 		cmd.append('--pwdfile=%s' % self.admin_pwdfile)
 		cmd.append('%s=%s' % (self.app_name, self.app_version))
 		print(cmd)
-		ret = subprocess.call(' '.join(cmd), shell=True)
-		if ret != 0:
-			raise UCSTest_DockerApp_UpgradeFailed()
+		error_handling_call(' '.join(cmd), shell=True, exc=UCSTest_DockerApp_UpgradeFailed)
 		self.reload_container_id()
 		self.installed = True
 
 	def verify(self, joined=True):
 		print('App.verify(%r)' % (joined,))
-		ret = subprocess.call('univention-app status %s=%s' % (self.app_name, self.app_version), shell=True)
-		if ret != 0:
-			raise UCSTest_DockerApp_VerifyFailed()
+		error_handling_call('univention-app status %s=%s' % (self.app_name, self.app_version), shell=True, exc=UCSTest_DockerApp_VerifyFailed)
 
 		if joined:
-			ret = subprocess.call('docker exec %s univention-check-join-status' % self.container_id, stderr=subprocess.STDOUT, shell=True)
-			if ret != 0:
-				raise UCSTest_DockerApp_VerifyFailed()
+			error_handling_call('docker exec %s univention-check-join-status' % self.container_id, shell=True, exc=UCSTest_DockerApp_VerifyFailed)
 
 		if self.package:
 			try:
@@ -450,9 +443,7 @@ class App(object):
 			cmd.append('--pwdfile=%s' % self.admin_pwdfile)
 			cmd.append('%s=%s' % (self.app_name, self.app_version))
 			print(cmd)
-			ret = subprocess.call(' '.join(cmd), shell=True)
-			if ret != 0:
-				raise UCSTest_DockerApp_RemoveFailed()
+			error_handling_call(' '.join(cmd), shell=True, exc=UCSTest_DockerApp_RemoveFailed)
 
 	def execute_command_in_container(self, cmd):
 		print('Execute: %s' % cmd)
@@ -514,7 +505,7 @@ echo "TEST-%(app_name)s" >>/var/www/%(app_name)s/index.txt
 
 	def configure_tinyapp_modproxy(self):
 		fqdn = '%(hostname)s.%(domainname)s' % self.ucr
-		self.execute_command_in_container('apk update')
+		self.execute_command_in_container('apk update --allow-untrusted')
 		self.execute_command_in_container('apk upgrade')
 		self.execute_command_in_container('apk add apache2-ssl')
 		self.execute_command_in_container("sed -i 's#/var/www/localhost/htdocs#/web/html#g' /etc/apache2/conf.d/ssl.conf")
@@ -552,7 +543,7 @@ echo "TEST-%(app_name)s" >>/var/www/%(app_name)s/index.txt
 				)
 
 
-class Appcenter(object):
+class Appcenter:
 	def __init__(self, version=None):
 		self.meta_inf_created = False
 		self.univention_repository_created = False
