@@ -34,7 +34,7 @@ class WriteFail(Exception):
 	pass
 
 
-class BaseMailClient(object):
+class BaseMailClient:
 	"""BaseMailClient is a Base (interface) for imaplib.IMAP4_SSL and imaplib.IMAP4
 	Does not work alone, can be used only as a super class of other child class.
 	"""
@@ -112,7 +112,7 @@ class BaseMailClient(object):
 			x = acl[0].split('"', 1)[1]
 			y = acl[1].split('"', 1)[0]
 			acl[0] = "%s %s" % (x, y)
-			del(acl[1])
+			del acl[1]
 		i = iter(acl[1:])
 		d = dict(zip(i, i))
 		return {acl[0]: d}
