@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Selenium Tests
 #
@@ -33,7 +32,6 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-from __future__ import absolute_import
 
 import logging
 from typing import Any, Callable, Iterable, List  # noqa: F401
@@ -47,29 +45,29 @@ from univention.testing.selenium.utils import expand_path
 logger = logging.getLogger(__name__)
 
 
-class ChecksAndWaits(object):
+class ChecksAndWaits:
 
 	def wait_for_text(self, text, timeout=60):
 		# type: (str, int) -> None
 		logger.info("Waiting for text: %r", text)
-		xpath = '//*[contains(text(), "%s")]' % (text,)
+		xpath = f'//*[contains(text(), "{text}")]'
 		webdriver.support.ui.WebDriverWait([xpath], timeout).until(
-			self.get_all_visible_elements, 'waited %s seconds for text %r' % (timeout, text)
+			self.get_all_visible_elements, f'waited {timeout} seconds for text {text!r}'
 		)
 
 	def wait_for_any_text_in_list(self, texts, timeout=60):
 		# type: (Iterable[str], int) -> None
 		logger.info("Waiting until any of those texts is visible: %r", texts)
-		xpaths = ['//*[contains(text(), "%s")]' % (text,) for text in texts]
+		xpaths = [f'//*[contains(text(), "{text}")]' for text in texts]
 		webdriver.support.ui.WebDriverWait(xpaths, timeout).until(
-			self.get_all_visible_elements, 'waited %s seconds for texts %r' % (timeout, texts)
+			self.get_all_visible_elements, f'waited {timeout} seconds for texts {texts!r}'
 		)
 
 	def wait_for_text_to_disappear(self, text, timeout=60):
 		# type: (object, int) -> None
-		xpath = '//*[contains(text(), "%s")]' % (text,)
+		xpath = f'//*[contains(text(), "{text}")]'
 		webdriver.support.ui.WebDriverWait(xpath, timeout).until(
-			self.elements_invisible, 'waited %s seconds for text %r to disappear' % (timeout, text)
+			self.elements_invisible, f'waited {timeout} seconds for text {text!r} to disappear'
 		)
 
 	def wait_for_button(self, button_text, **kwargs):
@@ -94,7 +92,7 @@ class ChecksAndWaits(object):
 		logger.info("Waiting for all standby animations to disappear.")
 		xpath = expand_path('//*[contains(@id, "_Standby_")]//*[@containsClass="umcStandbySvgWrapper"]')
 		webdriver.support.ui.WebDriverWait(xpath, timeout).until(
-			self.elements_invisible, 'wait_until_all_standby_animations_disappeared(timeout=%r)' % (timeout,)
+			self.elements_invisible, f'wait_until_all_standby_animations_disappeared(timeout={timeout!r})'
 		)
 
 	def wait_until_standby_animation_appears(self, timeout=5):
@@ -103,7 +101,7 @@ class ChecksAndWaits(object):
 		xpath = expand_path('//*[contains(@id, "_Standby_")]//*[@containsClass="umcStandbySvgWrapper"]')
 		try:
 			webdriver.support.ui.WebDriverWait(xpath, timeout).until(
-				self.elements_visible, 'wait_until_standby_animation_appears(timeout=%r)' % (timeout,)
+				self.elements_visible, f'wait_until_standby_animation_appears(timeout={timeout!r})'
 			)
 		except selenium_exceptions.TimeoutException:
 			logger.info("No standby animation appeared during timeout. Ignoring")
@@ -120,12 +118,12 @@ class ChecksAndWaits(object):
 		logger.info("Waiting for all progress bars to disappear.")
 		xpath = '//*[contains(concat(" ", normalize-space(@class), " "), " umcProgressBar ")]'
 		webdriver.support.ui.WebDriverWait(xpath, timeout=timeout).until(
-			self.elements_invisible, 'waited %s seconds for progress bar' % (timeout,)
+			self.elements_invisible, f'waited {timeout} seconds for progress bar'
 		)
 
 	def wait_until_element_visible(self, xpath, timeout=60):
 		# type: (str, int) -> None
-		logger.info('Waiting for the element with the xpath %r to be visible.' % (xpath,))
+		logger.info(f'Waiting for the element with the xpath {xpath!r} to be visible.')
 		self.wait_until(
 			expected_conditions.visibility_of_element_located(
 				(webdriver.common.by.By.XPATH, xpath)
@@ -136,7 +134,7 @@ class ChecksAndWaits(object):
 	def wait_until(self, check_function, timeout=60):
 		# type: (Callable[..., Any], int) -> None
 		webdriver.support.ui.WebDriverWait(self.driver, timeout).until(
-			check_function, 'wait_until(%r, timeout=%r)' % (check_function, timeout)
+			check_function, f'wait_until({check_function!r}, timeout={timeout!r})'
 		)
 
 	def get_gallery_items(self):
